# Changelog

## 0.4.0 (2023-11-20)

#### New Features
- Improve error description, add handler for NodeExecutionError (#47)
- Limit some traceback sizes (#51)
- Add new operations `migas.operations.add_breadcrumb` & `migas.operations.check_project` (#45)
- Improve same-user detection in Docker environments (#33)
- Add helper function to send breadcrumb on termination (#41)

#### Fixes
- Allow request to handle compressed data (#36)
- Do not accept brotli-compressed responses (#43)

#### Refactors
- Move to pyproject.toml & hatchling packaging (#42)

#### Deprecations
- `add_project` (#45)

#### Other
- Test operations on local server (#32)

Full set of changes: [`0.3.0...0.4.0`](https://github.com/nipreps/migas-py/compare/0.3.0...0.4.0)

## 0.3.0 (2022-10-24)


Full set of changes: [`0.2.1...0.3.0`](https://github.com/nipreps/migas-py/compare/0.2.1...0.3.0)

## 0.2.1 (2022-08-15)


Full set of changes: [`0.2.0...0.2.1`](https://github.com/nipreps/migas-py/compare/0.2.0...0.2.1)

## 0.2.0 (2022-08-10)


Full set of changes: [`0.1.1...0.2.0`](https://github.com/nipreps/migas-py/compare/0.1.1...0.2.0)

## 0.1.1 (2022-07-14)


Full set of changes: [`0.1.0...0.1.1`](https://github.com/nipreps/migas-py/compare/0.1.0...0.1.1)

## 0.1.0 (2022-07-14)


Full set of changes: [`0.0.4...0.1.0`](https://github.com/nipreps/migas-py/compare/0.0.4...0.1.0)

## 0.0.4 (2022-07-11)


Full set of changes: [`0.0.3...0.0.4`](https://github.com/nipreps/migas-py/compare/0.0.3...0.0.4)

## 0.0.3 (2022-07-11)


Full set of changes: [`0.0.2...0.0.3`](https://github.com/nipreps/migas-py/compare/0.0.2...0.0.3)

## 0.0.2 (2022-07-11)


Full set of changes: [`0.0.1...0.0.2`](https://github.com/nipreps/migas-py/compare/0.0.1...0.0.2)

## 0.0.1 (2022-07-08)

